@@ -3,9 +3,9 @@
  *
  * TOMOYO Linux's utilities.
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.6.6   2009/02/02
+ * Version: 1.6.9   2011/04/01
  *
  */
 #include "ccstools.h"
@@ -114,7 +114,7 @@ char *simple_readline(const int start_y, const int start_x, const char *prompt,
 	int line_pos = 0;
 	int cur_pos = 0;
 	int history_pos = 0;
-	bool tmp_saved = false;
+	_Bool tmp_saved = false;
 	static char *buffer = NULL;
 	static char *tmp_buffer = NULL;
 	{
