@@ -2,12 +2,13 @@
 #
 # Initial policy generator.
 #
-# Copyright (C) 2005-2008  NTT DATA CORPORATION
+# Copyright (C) 2005-2011  NTT DATA CORPORATION
 #
-# Version: 1.6.1   2008/05/10
+# Version: 1.6.9   2011/04/01
 #
 
 cd ${0%/*}
+set -f
 export PATH=$PWD:/sbin:/bin:${PATH}
 
 PROFILE_TYPE="--full-profile"
@@ -28,6 +29,21 @@ if ! realpath -n / > /dev/null; then
     exit 1
 fi
 
+if ! pathmatch / > /dev/null; then
+    echo "Can't execute program. Please make sure you installed correct package."
+    exit 1
+fi
+
+if ! which which > /dev/null; then
+    echo "Can't execute 'which' command. Please install package containing 'which' command."
+    exit 1
+fi
+
+if ! find . > /dev/null; then
+    echo "Can't execute 'find' command. Please install package containing 'find' command."
+    exit 1
+fi
+
 make_exception() {
 	#
 	# Make /sbin/modprobe and /sbin/hotplug as initializers, for they can be called by untrusted programs.
@@ -40,25 +56,28 @@ make_exception() {
 	#
 	# Make patterns for /proc/[number]/ and /proc/self/ directory.
 	#
-	for i in `find /proc/1/ /proc/self/ -type f`
+	for i in `find /proc/1/ /proc/self/ -type f 2> /dev/null`
 	do
-		echo "file_pattern "$i | sed 's@/[0-9]*/@/\\$/@g'
-	done | sort | uniq
+		echo "file_pattern "$i | sed -e 's@/[0-9]*/@/\\$/@g' -e 's@/[0-9]*$@/\\$@'
+	done | sort | uniq | grep -F '\'
 	
 	#
 	# Make patterns for /sys/ directory.
 	#
-	if [ -e /sys/block/ ]
-	then
-		for i in /sys/*
-		do
-			for j in `find $i | awk -F / ' { print NF-1 }'`
-			do
-				echo -n "file_pattern "$i; for k in `seq 3 $j`; do echo -n '/\*'; done; echo
-			done
-		done | grep -F '\' | sort | uniq
-	fi
-      
+	#if [ -e /sys/block/ ]
+	#then
+	#    set +f
+	#    DIRS=`echo /sys/*`
+	#    set -f
+	#    for DIR in $DIRS
+	#    do
+	#	for i in `find $DIR | awk -F / ' { print NF-1 }'`
+	#	do
+	#	    echo -n "file_pattern "$DIR; for j in `seq 3 $i`; do echo -n '/\*'; done; echo
+	#	done
+	#    done | grep -F '\' | sort | uniq
+	#fi
+	
 	#
 	# Make patterns for /dev/ directory.
 	#
@@ -76,12 +95,12 @@ make_exception() {
 	#
 	# Make patterns for man directory.
 	#
-	for i in `find /usr/share/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
+	[ -d /usr/share/man/ ] && for i in `find /usr/share/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
 		echo -n "file_pattern /usr/share/man"; for j in `seq 5 $i`; do echo -n '/\*'; done; echo
 	done
       
-	for i in `find /usr/X11R6/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
+	[ -d /usr/X11R6/man/ ] && for i in `find /usr/X11R6/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
 		echo -n "file_pattern /usr/X11R6/man"; for j in `seq 5 $i`; do echo -n '/\*'; done; echo
 	done
@@ -95,6 +114,8 @@ make_exception() {
 	done
 	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/'
 	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/\X'
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/defer/\x/'
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/defer/\x/\X'
 	
 	#
 	# Make patterns for man(1).
@@ -114,19 +135,63 @@ make_exception() {
 	#
 	# Allow reading some data files.
 	#
-	for i in /etc/ld.so.cache /proc/meminfo /proc/sys/kernel/version /etc/localtime /usr/lib/gconv/gconv-modules.cache /usr/lib/locale/locale-archive /usr/share/locale/locale.alias /usr/share/locale/ja/LC_MESSAGES/coreutils.mo /usr/share/locale/ja/LC_MESSAGES/libc.mo
+	for i in /etc/ld.so.cache /proc/meminfo /proc/sys/kernel/version /etc/localtime /usr/lib/gconv/gconv-modules.cache /usr/share/locale/locale.alias
 	do
 		FILE=`realpath $i`
 		[ -n "$FILE" -a -r "$FILE" -a ! -L "$FILE" ] && echo 'allow_read '$FILE
 	done
-	
+	set -f
+	for dir in `realpath -n /usr/share/` `realpath -n /usr/lib/`
+	  do
+	  if [ -d $dir ]; then
+        # Allow reading font files.
+	      for i in `find $dir -type d -name '*fonts*'`
+		do
+		for j in '/\*' '/\*/\*' '/\*/\*/\*' '/\*/\*/\*/\*' '/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*/\*'
+		  do
+		  pathmatch $i$j | grep -q / && echo 'allow_read '$i$j
+		done
+	      done
+        # Allow reading icon files.
+	      for i in `find $dir -type d -name '*icons*'`
+		do
+		for j in '/\*' '/\*/\*' '/\*/\*/\*' '/\*/\*/\*/\*' '/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*/\*'
+		  do
+		  pathmatch $i$j | grep -q / && echo 'allow_read '$i$j
+		done
+	      done
+        # Allow reading locale files.
+	      for i in `find $dir -type d -name 'locale'`
+		do
+		for j in '/\*' '/\*/\*' '/\*/\*/\*' '/\*/\*/\*/\*' '/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*/\*'
+		  do
+		  pathmatch $i$j | grep -q / && echo 'allow_read '$i$j
+		done
+	      done
+	      for i in `find $dir -type d -name 'locales'`
+		do
+		for j in '/\*' '/\*/\*' '/\*/\*/\*' '/\*/\*/\*/\*' '/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*/\*'
+		  do
+		  pathmatch $i$j | grep -q / && echo 'allow_read '$i$j
+		done
+	      done
+	      for i in `find $dir -type d -name 'locale-langpack'`
+		do
+		for j in '/\*' '/\*/\*' '/\*/\*/\*' '/\*/\*/\*/\*' '/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*' '/\*/\*/\*/\*/\*/\*/\*/\*/\*'
+		  do
+		  pathmatch $i$j | grep -q / && echo 'allow_read '$i$j
+		done
+	      done
+	  fi
+	done
+
 	#
 	# Allow reading information for current process.
 	#
-	for i in `find /proc/self/ -type f | grep -v '[0-9]'`
+	for i in `find /proc/self/ -type f 2> /dev/null`
 	do
-		echo 'allow_read '$i
-	done
+		echo 'allow_read '$i | sed -e 's@/[0-9]*/@/\\$/@g' -e 's@/[0-9]*$@/\\$@'
+	done | sort | uniq
 	
 	#
 	# Allow reading DLL files registered with ldconfig(8).
@@ -140,21 +205,23 @@ make_exception() {
 	#
 	# Mark programs under /etc/init.d/ directory as initializer.
 	#
-	for FILE in `for i in /etc/init.d/*; do realpath $i; done | sort | uniq`
-	do
-		[ -n "$FILE" -a -f "$FILE" -a -x "$FILE" -a ! -L "$FILE" ] && echo "initialize_domain "$FILE
-	done
+	DIR=`realpath /etc/init.d/`
+	if [ -n "$DIR" ]; then
+	    set +f
+	    FILES=`echo $DIR/*`
+	    set -f
+	    for FILE in $FILES
+	    do
+		[ -n "$FILE" -a -f "$FILE" -a -x "$FILE" ] && echo "initialize_domain "$FILE
+	    done
+	fi
 	
 	#
 	# Mark some programs that you want to assign short domainname as initializer.
 	#
-	# RHL9:  /sbin/cardmgr /sbin/klogd /sbin/mingetty /sbin/portmap /sbin/rpc.statd /sbin/syslogd /usr/bin/jserver /usr/bin/spamd /usr/sbin/anacron /usr/sbin/apmd /usr/sbin/atd /usr/sbin/crond /usr/sbin/dhcpd /usr/sbin/gpm /usr/sbin/httpd /usr/sbin/nmbd /usr/sbin/rpc.mountd /usr/sbin/rpc.rquotad /usr/sbin/sendmail.sendmail /usr/sbin/smbd /usr/sbin/sshd /usr/sbin/vsftpd /usr/sbin/xinetd
-	# FC3:   /sbin/cardmgr /sbin/klogd /sbin/mingetty /sbin/portmap /sbin/rpc.statd /sbin/syslogd /sbin/udevd /usr/X11R6/bin/xfs /usr/bin/dbus-daemon-1 /usr/bin/mDNSResponder /usr/bin/nifd /usr/sbin/acpid /usr/sbin/anacron /usr/sbin/atd /usr/sbin/cannaserver /usr/sbin/cpuspeed /usr/sbin/crond /usr/sbin/cupsd /usr/sbin/gpm /usr/sbin/hald /usr/sbin/htt /usr/sbin/nmbd /usr/sbin/rpc.idmapd /usr/sbin/rpc.mountd /usr/sbin/rpc.rquotad /usr/sbin/smartd /usr/sbin/smbd /usr/sbin/sshd /usr/sbin/xinetd
-	# Sarge: /sbin/getty /sbin/klogd /sbin/portmap /sbin/rpc.statd /sbin/syslogd /usr/sbin/afpd /usr/sbin/apache2 /usr/sbin/atalkd /usr/sbin/atd /usr/sbin/cron /usr/sbin/exim4 /usr/sbin/inetd /usr/sbin/lpd /usr/sbin/nmbd /usr/sbin/papd /usr/sbin/smbd /usr/sbin/sshd /usr/sbin/vmware-guestd
+	# You can add as you like to the list below.
 	#
-	# You can choose from the list above or add as you like to the list below.
-	#
-	for FILE in /sbin/getty /sbin/init /sbin/mingetty /sbin/udevd /usr/sbin/anacron /usr/sbin/apache2 /usr/sbin/atd /usr/sbin/cron /usr/sbin/crond /usr/sbin/httpd /usr/sbin/inetd /usr/sbin/logrotate /usr/sbin/smbd /usr/sbin/squid /usr/sbin/sshd /usr/sbin/vsftpd /usr/sbin/xinetd
+	for FILE in /sbin/cardmgr /sbin/getty /sbin/init /sbin/klogd /sbin/mingetty /sbin/portmap /sbin/rpc.statd /sbin/syslogd /sbin/udevd /usr/X11R6/bin/xfs /usr/bin/dbus-daemon-1 /usr/bin/jserver /usr/bin/mDNSResponder /usr/bin/nifd /usr/bin/spamd /usr/sbin/acpid /usr/sbin/afpd /usr/sbin/anacron /usr/sbin/apache2 /usr/sbin/apmd /usr/sbin/atalkd /usr/sbin/atd /usr/sbin/cannaserver /usr/sbin/cpuspeed /usr/sbin/cron /usr/sbin/crond /usr/sbin/cupsd /usr/sbin/dhcpd /usr/sbin/exim4 /usr/sbin/gpm /usr/sbin/hald /usr/sbin/htt /usr/sbin/httpd /usr/sbin/inetd /usr/sbin/logrotate /usr/sbin/lpd /usr/sbin/nmbd /usr/sbin/papd /usr/sbin/rpc.idmapd /usr/sbin/rpc.mountd /usr/sbin/rpc.rquotad /usr/sbin/sendmail.sendmail /usr/sbin/smartd /usr/sbin/smbd /usr/sbin/squid /usr/sbin/sshd /usr/sbin/vmware-guestd /usr/sbin/vsftpd /usr/sbin/xinetd
 	do
 		FILE=`realpath $FILE 2> /dev/null`
 		[ -n "$FILE" -a -f "$FILE" -a -x "$FILE" -a ! -L "$FILE" ] && echo 'initialize_domain '$FILE
@@ -193,7 +260,7 @@ make_exception() {
 	#
 	# Make patterns for spamd(1).
 	#
-	SPAMD_PATH=`which spamd`
+	SPAMD_PATH=`which spamd 2> /dev/null`
 	if [ -n "$SPAMD_PATH" ]; then
 		if grep -qF '/tmp/spamassassin-$$' $SPAMD_PATH; then
 			echo 'file_pattern /tmp/spamassassin-\$/'
@@ -210,7 +277,7 @@ make_exception() {
 	#
 	# Make patterns for mail(1).
 	#
-	MAIL_PATH=`which mail`
+	MAIL_PATH=`which mail 2> /dev/null`
 	if [ -n "$MAIL_PATH" ]; then
 		grep -qF '/mail.XXXXXX'       $MAIL_PATH && echo 'file_pattern /tmp/mail.\?\?\?\?\?\?'
 		grep -qF '/mail.RsXXXXXXXXXX' $MAIL_PATH && echo 'file_pattern /tmp/mail.RsXXXX\?\?\?\?\?\?'
@@ -261,7 +328,7 @@ make_exception() {
 	#
 	# Make patterns for gpm(8).
 	#
-	GPM_PATH=`which gpm`
+	GPM_PATH=`which gpm 2> /dev/null`
 	[ -n "$GPM_PATH" ] && grep -qF '/gpmXXXXXX' $GPM_PATH && echo 'file_pattern /var/run/gpm\?\?\?\?\?\?'
 	
 	#
@@ -293,7 +360,7 @@ make_exception() {
 	#
 	# Make patterns for makewhatis(8).
 	#
-	MAKEWHATIS_PATH=`which makewhatis`
+	MAKEWHATIS_PATH=`which makewhatis 2> /dev/null`
 	if [ -n "$MAKEWHATIS_PATH" ]; then
 		if grep -qF '/tmp/makewhatisXXXXXX' $MAKEWHATIS_PATH; then
 			echo 'file_pattern /tmp/makewhatis\?\?\?\?\?\?/'
@@ -307,7 +374,7 @@ make_exception() {
 	#
 	# Make patterns for automount(8).
 	#
-	AUTOMOUNT_PATH=`which automount`
+	AUTOMOUNT_PATH=`which automount 2> /dev/null`
 	if [ -n "$AUTOMOUNT_PATH" ]; then
 		if grep -qF '/var/lock/autofs' $AUTOMOUNT_PATH; then
 			echo 'file_pattern /var/lock/autofs.\$'
@@ -318,7 +385,7 @@ make_exception() {
 	#
 	# Make patterns for logwatch(8).
 	#
-	LOGWATCH_PATH=`which logwatch`
+	LOGWATCH_PATH=`which logwatch 2> /dev/null`
 	if [ -n "$LOGWATCH_PATH" ]; then
 		if grep -qF '/var/cache/logwatch' $LOGWATCH_PATH; then
 			echo 'file_pattern /var/cache/logwatch/logwatch.XX\?\?\?\?\?\?/'
@@ -332,7 +399,7 @@ make_exception() {
 	#
 	# Make patterns for logrotate(8).
 	#
-	LOGROTATE_PATH=`which logrotate`
+	LOGROTATE_PATH=`which logrotate 2> /dev/null`
 	if [ -n "$LOGROTATE_PATH" ]; then
 		if grep -qF '/logrotate.XXXXXX' $LOGROTATE_PATH; then
 			echo 'file_pattern /tmp/logrotate.\?\?\?\?\?\?'
@@ -343,7 +410,7 @@ make_exception() {
 	#
 	# Make patterns for cardmgr(8).
 	#
-	CARDMGR_PATH=`which cardmgr`
+	CARDMGR_PATH=`which cardmgr 2> /dev/null`
 	if [ -n "$CARDMGR_PATH" ]; then
 		if grep -qF '%s/cm-%d-%d' $CARDMGR_PATH; then
 			echo 'file_pattern /var/lib/pcmcia/cm-\$-\$'
@@ -353,7 +420,7 @@ make_exception() {
 	#
 	# Make patterns for anacron(8).
 	#
-	ANACRON_PATH=`which anacron`
+	ANACRON_PATH=`which anacron 2> /dev/null`
 	if [ -n "$ANACRON_PATH" ]; then
 		echo 'file_pattern /tmp/file\?\?\?\?\?\?'
 	fi
@@ -366,6 +433,53 @@ make_exception() {
 		echo 'file_pattern /tmp/run-crons.\?\?\?\?\?\?/run-crons.\*'
 	fi
 	
+	#
+	# Make patterns for postgresql.
+	#
+	if [ -d /var/lib/pgsql/ ]; then
+		echo 'file_pattern /var/lib/pgsql/data/base/\$/'
+		echo 'file_pattern /var/lib/pgsql/data/base/\$/\$'
+		echo 'file_pattern /var/lib/pgsql/data/base/global/pg_database.\$'
+		echo 'file_pattern /var/lib/pgsql/data/base/\$/pg_internal.init.\$'
+		echo 'file_pattern /var/lib/pgsql/data/base/\$/pg_internal.init'
+		echo 'file_pattern /var/lib/pgsql/data/base/pgsql_tmp/pgsql_tmp\*'
+		echo 'file_pattern /var/lib/pgsql/data/base/\$/PG_VERSION'
+		echo 'file_pattern /var/lib/pgsql/data/global/\$'
+		echo 'file_pattern /var/lib/pgsql/data/global/pg_auth.\$'
+		echo 'file_pattern /var/lib/pgsql/data/global/pg_database.\$'
+		echo 'file_pattern /var/lib/pgsql/data/pg_clog/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_multixact/members/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_multixact/offsets/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_subtrans/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_tblspc/\$'
+		echo 'file_pattern /var/lib/pgsql/data/pg_twophase/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_xlog/\X'
+		echo 'file_pattern /var/lib/pgsql/data/pg_xlog/xlogtemp.\$'
+	fi
+	if [ -d /var/lib/postgres/ ]; then
+		echo 'file_pattern /var/lib/postgres/data/base/\$/'
+		echo 'file_pattern /var/lib/postgres/data/base/\$/\$'
+		echo 'file_pattern /var/lib/postgres/data/global/\$'
+		echo 'file_pattern /var/lib/postgres/data/global/pgstat.tmp.\$'
+		echo 'file_pattern /var/lib/postgres/data/pg_clog/\X'
+		echo 'file_pattern /var/lib/postgres/data/pg_xlog/\X'
+	fi
+	if [ -d /var/lib/postgresql/ ]; then
+		echo 'file_pattern /var/lib/postgresql/\*/main/base/\$/'
+		echo 'file_pattern /var/lib/postgresql/\*/main/base/\$/\$'
+		echo 'file_pattern /var/lib/postgresql/\*/main/base/\$/pg_internal.init.\$'
+		echo 'file_pattern /var/lib/postgresql/\*/main/base/\$/PG_VERSION'
+		echo 'file_pattern /var/lib/postgresql/\*/main/global/\$'
+		echo 'file_pattern /var/lib/postgresql/\*/main/global/\$/pg_auth.\$'
+		echo 'file_pattern /var/lib/postgresql/\*/main/global/\$/pg_database.\$'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_clog/\X'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_multixact/members/\X'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_multixact/offsets/\X'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_subtrans/\X'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_xlog/\X'
+		echo 'file_pattern /var/lib/postgresql/\*/main/pg_xlog/xlogtemp.\$'
+	fi
+	
 	#
 	# Miscellaneous patterns.
 	#
@@ -400,22 +514,43 @@ make_exception() {
 		echo 'file_pattern /var/run/nscd/db\?\?\?\?\?\?'
 	fi
 	
+	if [ -d /var/lib/init.d/ ]; then
+	    echo 'file_pattern /var/lib/init.d/mtime-test.\$'
+	    echo 'file_pattern /var/lib/init.d/exclusive/\*.\$'
+	    echo 'file_pattern /var/lib/init.d/depcache.\?\?\?\?\?\?\?'
+	    echo 'file_pattern /var/lib/init.d/treecache.\?\?\?\?\?\?\?'
+	fi
+	
+	echo 'file_pattern /etc/group.\$'
+	echo 'file_pattern /etc/gshadow.\$'
+	echo 'file_pattern /etc/passwd.\$'
+	echo 'file_pattern /etc/shadow.\$'
+	echo 'file_pattern /var/cache/logwatch/logwatch.\*/'
+	echo 'file_pattern /var/cache/logwatch/logwatch.\*/\*'
+	echo 'file_pattern /var/tmp/sqlite_\*'
 	echo 'file_pattern /tmp/ib\?\?\?\?\?\?'
 	echo 'file_pattern /tmp/PerlIO_\?\?\?\?\?\?'
-
+	[ -d /var/run/hald/ ] && echo 'file_pattern /var/run/hald/acl-list.\?\?\?\?\?\?'
+	if [ -d /usr/share/zoneinfo/ ]; then
+		echo 'file_pattern /usr/share/zoneinfo/\*'
+		echo 'file_pattern /usr/share/zoneinfo/\*/\*'
+		echo 'file_pattern /usr/share/zoneinfo/\*/\*/\*'
+		echo 'file_pattern /usr/share/zoneinfo/\*/\*/\*/\*'
+	fi
+	
 	#
 	# Make /var/log/ directory not rewritable by default.
 	#
-	for i in `find /var/log/ -type f | awk -F / ' { print NF }' | sort | uniq`
+	[ -d /var/log/ ] && for i in `find /var/log/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
 		echo -n "deny_rewrite /var/log"; for j in `seq 4 $i`; do echo -n '/\*'; done; echo
 	done
 }
 
 make_alias() {
-	for MNT in `df | awk ' { print $NF } ' | grep / | sort | uniq`
+	for MNT in `df 2> /dev/null | awk ' { print $NF } ' | grep / | sort | uniq`
 	do
-		for SYMLINK in `find $MNT -xdev -type l`
+		[ -d $MNT ] && for SYMLINK in `find $MNT -xdev -type l 2> /dev/null`
 		do
 			
 			# Solve symbolic name.
@@ -482,6 +617,7 @@ EOF
 		cat > /etc/ccs/profile.conf << EOF
 0-COMMENT=-----Disabled Mode-----
 0-MAC_FOR_FILE=disabled
+0-MAC_FOR_IOCTL=disabled
 0-MAC_FOR_ARGV0=disabled
 0-MAC_FOR_ENV=disabled
 0-MAC_FOR_NETWORK=disabled
@@ -496,7 +632,6 @@ EOF
 0-MAX_GRANT_LOG=1024
 0-MAX_REJECT_LOG=1024
 0-TOMOYO_VERBOSE=enabled
-0-ALLOW_ENFORCE_GRACE=disabled
 0-SLEEP_PERIOD=0
 0-MAC_FOR_CAPABILITY::inet_tcp_create=disabled
 0-MAC_FOR_CAPABILITY::inet_tcp_listen=disabled
@@ -531,6 +666,7 @@ EOF
 0-MAC_FOR_CAPABILITY::SYS_PTRACE=disabled
 1-COMMENT=-----Learning Mode-----
 1-MAC_FOR_FILE=learning
+1-MAC_FOR_IOCTL=learning
 1-MAC_FOR_ARGV0=learning
 1-MAC_FOR_ENV=learning
 1-MAC_FOR_NETWORK=learning
@@ -545,7 +681,6 @@ EOF
 1-MAX_GRANT_LOG=1024
 1-MAX_REJECT_LOG=1024
 1-TOMOYO_VERBOSE=disabled
-1-ALLOW_ENFORCE_GRACE=disabled
 1-SLEEP_PERIOD=0
 1-MAC_FOR_CAPABILITY::inet_tcp_create=learning
 1-MAC_FOR_CAPABILITY::inet_tcp_listen=learning
@@ -580,6 +715,7 @@ EOF
 1-MAC_FOR_CAPABILITY::SYS_PTRACE=learning
 2-COMMENT=-----Permissive Mode-----
 2-MAC_FOR_FILE=permissive
+2-MAC_FOR_IOCTL=permissive
 2-MAC_FOR_ARGV0=permissive
 2-MAC_FOR_ENV=permissive
 2-MAC_FOR_NETWORK=permissive
@@ -594,7 +730,6 @@ EOF
 2-MAX_GRANT_LOG=1024
 2-MAX_REJECT_LOG=1024
 2-TOMOYO_VERBOSE=enabled
-2-ALLOW_ENFORCE_GRACE=disabled
 2-SLEEP_PERIOD=0
 2-MAC_FOR_CAPABILITY::inet_tcp_create=permissive
 2-MAC_FOR_CAPABILITY::inet_tcp_listen=permissive
@@ -629,6 +764,7 @@ EOF
 2-MAC_FOR_CAPABILITY::SYS_PTRACE=permissive
 3-COMMENT=-----Enforcing Mode-----
 3-MAC_FOR_FILE=enforcing
+3-MAC_FOR_IOCTL=enforcing
 3-MAC_FOR_ARGV0=enforcing
 3-MAC_FOR_ENV=enforcing
 3-MAC_FOR_NETWORK=enforcing
@@ -643,7 +779,6 @@ EOF
 3-MAX_GRANT_LOG=1024
 3-MAX_REJECT_LOG=1024
 3-TOMOYO_VERBOSE=enabled
-3-ALLOW_ENFORCE_GRACE=disabled
 3-SLEEP_PERIOD=0
 3-MAC_FOR_CAPABILITY::inet_tcp_create=enforcing
 3-MAC_FOR_CAPABILITY::inet_tcp_listen=enforcing
@@ -684,7 +819,10 @@ fi
 if [ ! -r /etc/ccs/exception_policy.conf ]; then
 	echo Creating exception policy. This will take several minutes.
 	make_exception > /etc/ccs/exception_policy.conf
-	make_alias >> /etc/ccs/exception_policy.conf
+	### Old version. ###
+	# make_alias >> /etc/ccs/exception_policy.conf
+	### New version. ###
+	./make_alias | grep -v '/[SK][0-9][0-9]' >> /etc/ccs/exception_policy.conf
 fi
 if [ ! -r /etc/ccs/system_policy.conf ]; then
 	echo Creating system policy.
