@@ -3,9 +3,9 @@
  *
  * Testing program for fs/tomoyo_domain.c
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.6.6   2009/02/02
+ * Version: 1.6.9   2011/04/01
  *
  */
 #include "include.h"
@@ -17,6 +17,11 @@ int main(int raw_argc, char *raw_argv[])
 	char *cp2;
 	FILE *fp;
 	int error;
+	if (access(proc_policy_domain_policy, F_OK)) {
+		fprintf(stderr, "You can't use this program for this kernel."
+			"\n");
+		return 1;
+	}
 	ccs_test_init();
 	memset(buffer, 0, sizeof(buffer));
 	fp = fopen(proc_policy_process_status, "r+");
